from collections.abc import Generator
from typing import Optional, Union

from core.model_runtime.entities.llm_entities import LLMResult
from core.model_runtime.entities.message_entities import PromptMessage, PromptMessageTool
from core.model_runtime.entities.model_entities import AIModelEntity
from core.model_runtime.model_providers.openai_api_compatible.llm.llm import OAIAPICompatLargeLanguageModel


class OpenRouterLargeLanguageModel(OAIAPICompatLargeLanguageModel):

    def _update_credential(self, model: str, credentials: dict):
        credentials['endpoint_url'] = "https://openrouter.ai/api/v1"
        credentials['mode'] = self.get_model_mode(model).value
        credentials['function_calling_type'] = 'tool_call'
        return

    def _invoke(self, model: str, credentials: dict,
                prompt_messages: list[PromptMessage], model_parameters: dict,
                tools: Optional[list[PromptMessageTool]] = None, stop: Optional[list[str]] = None,
                stream: bool = True, user: Optional[str] = None) \
            -> Union[LLMResult, Generator]:
        self._update_credential(model, credentials)

        return super()._invoke(model, credentials, prompt_messages, model_parameters, tools, stop, stream, user)

    def validate_credentials(self, model: str, credentials: dict) -> None:
        self._update_credential(model, credentials)

        return super().validate_credentials(model, credentials)

    def _generate(self, model: str, credentials: dict, prompt_messages: list[PromptMessage], model_parameters: dict,
                  tools: Optional[list[PromptMessageTool]] = None, stop: Optional[list[str]] = None,
                  stream: bool = True, user: Optional[str] = None) -> Union[LLMResult, Generator]:
        self._update_credential(model, credentials)

        return super()._generate(model, credentials, prompt_messages, model_parameters, tools, stop, stream, user)

    def get_customizable_model_schema(self, model: str, credentials: dict) -> AIModelEntity:
        self._update_credential(model, credentials)

        return super().get_customizable_model_schema(model, credentials)

    def get_num_tokens(self, model: str, credentials: dict, prompt_messages: list[PromptMessage],
                       tools: Optional[list[PromptMessageTool]] = None) -> int:
        self._update_credential(model, credentials)

        return super().get_num_tokens(model, credentials, prompt_messages, tools)
